<?php

class Gallery {
	
	private $template;
	private $imgurl;
	private $files;
	private $titles = false;

	public $mainclass = 'gallery';
	public $thumbclass = 'thumb';
	public $linkclass = 'link';

	//---Asignar un template y un fichero de visualización de imágenes a la galería
	public function setData($templateurl, $show_thumb_url){

		//---Verificaciones
		if(file_exists($templateurl) && file_exists($show_thumb_url)){

			$template = file_get_contents($templateurl);

			if($template){

				$this->template = $template;

				$this->imgurl = $show_thumb_url;

			}else{

				trigger_error('No se ha podido leer el fichero del template', E_USER_ERROR);

			}

		}else{

			trigger_error('La ruta al template no es válida', E_USER_ERROR);

		}		

	}

	//--Asignar los titles
	public function setTitles($titles){

		//---Verificaciones
		if(is_array($titles)){

			$this->titles = $titles;

		}else{

			trigger_error('Los nombres deben estar conformados en un array', E_USER_ERROR);

		}

	}
	
	//---Método de leer las imágenes de la carpeta
	public function loadFolder($path, $ext = false){

		//---Extensiones permitidas
		$extensions = array('jpg', 'png', 'gif');

		if($ext && in_array($ext, $extensions) === FALSE){

			trigger_error('La extensión eviada no es válida', E_USER_ERROR);

			exit;

		}
		
		//---Rectificar el path a la carpeta
		if(substr($path, -1) != '/') $path .= '/';
		
		//---Acceder a todos los archivos de imagen del directorio
		$this->files = ($ext) ? glob($path . '*.' . $ext) : glob($path . '*.{jpg,png,gif}', GLOB_BRACE);

		if($this->files === FALSE) trigger_error('No se ha encontrado ningún fichero de imagen en la ruta especificada');
	
	}
	
	//---Método de crear la galería
	public function create($width = 150, $height = 150){

		//---Acceder al código donde se insertarán los thumbnails
		$thumbcode = preg_replace('/.*\{THUMBS\}(.*)\{\/THUMBS\}.*/s', '$1', $this->template);

		//---Asignar ancho y alto
		$thumbcode = preg_replace(

			array(

				'/\{WIDTH\}/',
				'/\{HEIGHT\}/'
			),

			array(

				$width,
				$height

			),

			$thumbcode

		);

		//---Remplazo de los elementos generales
		$html = preg_replace(

				array(
					'/\{CLASSES\}/',
					'/\{THUMBS\}.*\{\/THUMBS\}/s'
				),

				array(
					$this->mainclass,
					$this->getThumbCode($this->files, $thumbcode, $width, $height)
				),

				$this->template

		);

		echo $html;
	
	}

	//---Método privado para obtener el código html de un thumbnail
	private function getThumbCode($files, $thumbcode, $width, $height){

		//---Expresión regular para extraer la imagen de los paths
		$namereg = '/^.*\/([^\/]+)$/';
		$html = '';

		foreach($files as $path){

			//---Acceder a la imagen
			$title = preg_replace($namereg, '$1', $path);

			//---Remplazos de los elementos
			$html .= preg_replace(

				array(

					'/\{THUMBCLASS\}/',
					'/\{LINKCLASS\}/',
					'/\{IMAGE\}/',
					'/title=[\'"]\{TITLE\}[\'"]/',
					'/\{PATH\}/',
					'/\{WIDTH\}/',
					'/\{HEIGHT\}/'

				),

				array(

					$this->thumbclass,
					$this->linkclass,
					$path,
					($this->titles && array_key_exists($title, $this->titles)) ? 'title="' . $this->titles[$title] . '"' : '',
					$this->imgurl . '?src=' . $path . '&width=' . $width . '&height=' . $height,
					$width,
					$height

				),

				$thumbcode
			);

		}

		return $html;

	}

}

?>